@@ -44,7 +44,7 @@ class Turba_Driver_Share extends Turba_Driver
     {
         parent::__construct($name, $params);
         $this->_share = $this->_params['config']['params']['share'];
-        $this->_driver = $GLOBALS['injector']->getInstance('Turba_Factory_Driver')->create($this->_params['config'], $name);
+        $this->_driver = $GLOBALS['injector']->getInstance('Turba_Factory_Driver')->createFromConfig($this->_params['config'], $name);
         $this->_driver->setContactOwner($this->_getContactOwner());
         $this->_driver->setSourceName($name);
     }
